.. Rucio documentation master file, created by
   sphinx-quickstart on Fri Oct 27 14:25:40 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Rucio's documentation!
=================================

Rucio is a project that provides services and associated libraries for allowing scientific
collaborations to manage large volumes of data spread across facilities at
multiple institutions and organisations. Rucio has been developed by
`the ATLAS experiment <https://atlas.cern/>`_.

Rucio offers advanced features, is highly scalable and modular. It is a data management
solution that could cover the needs of different communities in the scientific
domain (e.g., HEP, astronomy, biology).

This documentation is generated by the `Sphinx toolkit`_. and lives in the `source tree`_.

.. _`Sphinx toolkit`: http://sphinx.pocoo.org/
.. _`source tree`: https://github.com/rucio/rucio/tree/master/doc/source

General Information
===================

This section contains the general information related to Rucio which is common to
all developers, users and operators.
For documentation specific to the any of these three, please see the subsequent sections.

.. toctree::
    :maxdepth: 1

    concepts
    replica_workflow
    architecture

Developer Documentation
=======================

If you want to develop with Rucio or contribute to the project, this part
of the documentation is for you.

.. toctree::
    :maxdepth: 1

    contributing
    developing
    rest
    api
    database

User Documentation
==================

.. toctree::
    :maxdepth: 1

    installing_clients
    man/rucio
    man/rucio-admin
    rse_expressions
    clients
    advanced_usage


Operator Documentation
======================

.. toctree::
    :maxdepth: 1

    installing_server
    installing_daemons
    man/daemons
    monitoring


Rucio Tutorial
==============

.. toctree::
    :maxdepth: 1

    installing_demo
    rucio_demo
    cli_examples
    cli_admin_examples

Authors
=======

.. toctree::
    :maxdepth: 1

    authors
